@@ -6,7 +6,7 @@ use warnings;
 # ABSTRACT: common tests to check syntax of your modules
 
 use Moose;
-use Class::MOP;
+use Module::Runtime 'use_module';
 require lib;
 
 with 'Dist::Zilla::Role::FileGatherer';
@@ -25,7 +25,7 @@ has lib => (
 
 sub mvp_multivalue_args { qw(lib) }
 
-unlink 't/lib/ddl.sql';
+unlink $_ for glob 't/lib/*.sql';
 
 sub gather_files {
    my $self = shift;
@@ -33,12 +33,12 @@ sub gather_files {
    lib->import(@{$self->lib});
 
    my $schema = $self->schema;
-   Class::MOP::load_class($schema);
+   use_module($schema);
 
    $schema->generate_ddl;
 
-   my $file = Dist::Zilla::File::OnDisk->new(name => $schema->ddl_filename);
-   $self->add_file($file);
+   $self->add_file( Dist::Zilla::File::OnDisk->new(name => $_))
+      for glob 't/lib/*.sql';
 }
 
 no Moose;
