@@ -15,6 +15,7 @@ __PACKAGE__->load_namespaces(
 __PACKAGE__->load_components(qw(
    Helper::Schema::LintContents
    Helper::Schema::QuoteNames
+   Helper::Schema::DidYouMean
 ));
 
 sub upgrade_directory { './t/lib' }
@@ -65,7 +66,7 @@ sub generate_ddl {
 
 sub prepopulate {
    my $self = shift;
-   $self->resultset($_)->delete for qw{Bar Foo Gnarly_Station Bloaty Gnarly Station};
+   $self->resultset($_)->delete for qw{Bar Foo Gnarly_Station Bloaty Gnarly Station HasAccessor};
 
    $self->populate( Gnarly => [
       [qw{id name}],
@@ -115,6 +116,13 @@ sub prepopulate {
       [4,4],
       [5,5],
    ]);
+
+   $self->populate( HasAccessor => [
+      [qw{id usable_column unusable_column}],
+      [1,'aa','bb'],
+      [2,'cc','dd'],
+      [3,'ee','ff'],
+   ]);
 }
 
 'kitten eater';
